Module analyzers

Module analyzers 

Re-exports

pub use auth_header_remover::AuthHeaderRemover;
pub use http_decompressor::HTTPDecompressor;
pub use http_filter::HTTPFilter;
pub use http_filter::print_global_http_filter_metrics;
pub use http_parser::HTTPParser;
pub use materializing::MaterializingAnalyzer;
pub use sse_processor::SSEProcessor;
pub use ssl_filter::SSLFilter;
pub use ssl_filter::print_global_ssl_filter_metrics;
pub use timestamp_normalizer::TimestampNormalizer;

Modules

auth_header_remover
common
http_decompressor
http_filter
http_parser
materializing
sse_processor
ssl_filter
timestamp_normalizer
Timestamp Normalizer Analyzer

Traits

Analyzer
Base trait for all analyzers that process event streams

Type Aliases

AnalyzerError
Type alias for errors that can be sent between threads