AuthHeaderRemover

Struct AuthHeaderRemover 

pub struct AuthHeaderRemover { /* private fields */ }
Authorization Header Remover Analyzer that removes authorization headers from HTTP events This analyzer should be used after HTTPFilter to clean sensitive data from HTTP traffic

Implementations

Source

impl AuthHeaderRemover

pub fn new() -> Self

Create a new AuthHeaderRemover with default authorization headers