Analyzer

Trait Analyzer 

pub trait Analyzer: Send + Sync {
    // Required method
    fn process<'life0, 'async_trait>(
        &'life0 mut self,
        stream: EventStream,
    ) -> Pin<Box<dyn Future<Output = Result<EventStream, AnalyzerError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
Base trait for all analyzers that process event streams

Required Methods

fn process<'life0, 'async_trait>( &'life0 mut self, stream: EventStream, ) -> Pin<Box<dyn Future<Output = Result<EventStream, AnalyzerError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Process an event stream and return a processed stream

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors