Module runners

Module runners 

Re-exports

pub use agent::AgentRunner;
pub use common::BinaryRunner;
pub use process::ProcessRunner;
pub use system::SystemRunner;

Modules

agent
common
process
system

Traits

Runner
Base trait for all runners that collect observability data

Type Aliases

EventStream
Type alias for event streams
RunnerError
Type alias for errors that can be sent between threads