pub struct AgentRunner { /* private fields */ }Expand description
AgentRunner composes multiple runners into a single unified stream with optional global analyzers applied to the merged stream
Implementations
Sourceimpl AgentRunner
impl AgentRunner
Sourcepub fn add_runner(self, runner: Box<dyn Runner>) -> Self
pub fn add_runner(self, runner: Box<dyn Runner>) -> Self
Add a pre-configured runner with its analyzer chain
Sourcepub fn add_global_analyzer(self, analyzer: Box<dyn Analyzer>) -> Self
pub fn add_global_analyzer(self, analyzer: Box<dyn Analyzer>) -> Self
Add analyzer that will be applied to the merged stream
Sourcepub fn runner_count(&self) -> usize
pub fn runner_count(&self) -> usize
Get the number of configured runners
Sourcepub fn analyzer_count(&self) -> usize
pub fn analyzer_count(&self) -> usize
Get the number of configured global analyzers