pub struct BinaryExecutor { /* private fields */ }Expand description
Common binary executor for runners - now supports streaming
Implementations
Sourceimpl BinaryExecutor
impl BinaryExecutor
pub fn new(binary_path: String) -> Self
pub fn with_args(self, args: &[String]) -> Self
pub fn set_args(&mut self, args: &[String])
pub fn with_runner_name(self, name: String) -> Self
Sourcepub async fn get_json_stream(&self) -> Result<JsonStream, RunnerError>
pub async fn get_json_stream(&self) -> Result<JsonStream, RunnerError>
Execute binary and get raw JSON stream.
When not running as root, automatically wraps the command with sudo so
eBPF programs get the privileges they need while the parent process
(and the user’s agent) stay unprivileged.