pub struct AgentRunner { /* private fields */ }Expand description
AgentRunner composes multiple runners into a single unified stream with optional global analyzers applied to the merged stream.
Implementations
Sourceimpl AgentRunner
impl AgentRunner
pub fn new() -> AgentRunner
pub fn add_runner(self, runner: Box<dyn Runner>) -> AgentRunner
pub fn add_global_analyzer(self, analyzer: Box<dyn Analyzer>) -> AgentRunner
pub fn runner_count(&self) -> usize
pub fn analyzer_count(&self) -> usize