Runner

Trait Runner 

pub trait Runner: Send + Sync {
    // Required methods
    fn run<'life0, 'async_trait>(
        &'life0 mut self,
    ) -> Pin<Box<dyn Future<Output = Result<EventStream, RunnerError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn add_analyzer(self, analyzer: Box<dyn Analyzer>) -> Self
       where Self: Sized;
}
Base trait for all runners that collect observability data

Required Methods

fn run<'life0, 'async_trait>( &'life0 mut self, ) -> Pin<Box<dyn Future<Output = Result<EventStream, RunnerError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Run the data collection and return a stream of events

fn add_analyzer(self, analyzer: Box<dyn Analyzer>) -> Self
where Self: Sized,

Add an analyzer to this runner’s processing chain

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors