Module time

Module time 

Timestamp conversion utilities

All timestamps in the system are standardized to milliseconds since UNIX epoch for consistency and ease of use in the frontend.

Functions

boot_ns_to_epoch_ms
Convert nanoseconds since boot to milliseconds since UNIX epoch
get_boot_time_secs
Get the system boot time in seconds since UNIX epoch