pub struct AuthHeaderRemover { /* private fields */ }Expand description
Authorization Header Remover Analyzer that removes authorization headers from HTTP events This analyzer should be used after HTTPFilter to clean sensitive data from HTTP traffic
Implementations