Re-exports
pub use agent::AgentRunner;pub use common::BinaryRunner;pub use process::ProcessRunner;pub use system::SystemRunner;
Modules
Traits
- Runner
- Base trait for all runners that collect observability data
Type Aliases
- Event
Stream - Type alias for event streams
- Runner
Error - Type alias for errors that can be sent between threads